@@ -34,7 +34,8 @@ struct MathWindowPrivate
 
 G_DEFINE_TYPE (MathWindow, math_window, GTK_TYPE_WINDOW);
 
-enum {
+enum
+{
     QUIT,
     LAST_SIGNAL
 };
@@ -51,13 +52,15 @@ math_window_new(MathEquation *equation)
 GtkWidget *
 math_window_get_menu_bar(MathWindow *window)
 {
-   return window->priv->menu_bar;
+    g_return_val_if_fail(window != NULL, NULL);
+    return window->priv->menu_bar;
 }
 
 
 MathEquation *
 math_window_get_equation(MathWindow *window)
 {
+    g_return_val_if_fail(window != NULL, NULL);
     return window->priv->equation;
 }
 
@@ -65,6 +68,7 @@ math_window_get_equation(MathWindow *window)
 MathDisplay *
 math_window_get_display(MathWindow *window)
 {
+    g_return_val_if_fail(window != NULL, NULL);
     return window->priv->display;
 }
 
@@ -72,6 +76,7 @@ math_window_get_display(MathWindow *window)
 MathButtons *
 math_window_get_buttons(MathWindow *window)
 {
+    g_return_val_if_fail(window != NULL, NULL);
     return window->priv->buttons;
 }
 
@@ -81,6 +86,10 @@ math_window_critical_error(MathWindow *window, const gchar *title, const gchar *
 {
     GtkWidget *dialog;
 
+    g_return_if_fail(window != NULL);
+    g_return_if_fail(title != NULL);
+    g_return_if_fail(contents != NULL);
+
     dialog = gtk_message_dialog_new(NULL, 0,
                                     GTK_MESSAGE_ERROR,
                                     GTK_BUTTONS_NONE,
@@ -154,7 +163,7 @@ help_cb(GtkWidget *widget, MathWindow *window)
     GError *error = NULL;
 
     screen = gtk_widget_get_screen(GTK_WIDGET(window));
-    gtk_show_uri(screen, "ghelp:gcalctool", gtk_get_current_event_time(), &error);
+    gtk_show_uri(screen, "help:gcalctool", gtk_get_current_event_time(), &error);
 
     if (error != NULL)
     {
@@ -241,6 +250,29 @@ key_press_cb(MathWindow *window, GdkEventKey *event)
 {
     gboolean result;
     g_signal_emit_by_name(window->priv->display, "key-press-event", event, &result);
+
+    if (math_buttons_get_mode (window->priv->buttons) == PROGRAMMING && (event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) {
+        switch(event->keyval)
+        {
+        /* Binary */
+        case GDK_KEY_b:
+            math_equation_set_base (window->priv->equation, 2);
+            return TRUE;
+        /* Octal */
+        case GDK_KEY_o:
+            math_equation_set_base (window->priv->equation, 8);
+            return TRUE;
+        /* Decimal */
+        case GDK_KEY_d:
+            math_equation_set_base (window->priv->equation, 10);
+            return TRUE;
+        /* Hexdecimal */
+        case GDK_KEY_h:
+            math_equation_set_base (window->priv->equation, 16);
+            return TRUE;
+        }
+    }
+
     return result;
 }
 
@@ -398,7 +430,7 @@ create_gui(MathWindow *window)
     GtkWidget *main_vbox, *vbox;
     GtkWidget *scrolled_window;
   
-    main_vbox = gtk_vbox_new(FALSE, 0);
+    main_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(window), main_vbox);
     gtk_widget_show(main_vbox);
 
@@ -408,7 +440,7 @@ create_gui(MathWindow *window)
   
     create_menu(window);
 
-    vbox = gtk_vbox_new(FALSE, 6);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 6);
     gtk_box_pack_start(GTK_BOX(main_vbox), vbox, TRUE, TRUE, 0);  
     gtk_widget_show(vbox);
