@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,58 +38,66 @@
       know about them.  */
    enum yytokentype {
      tNUMBER = 258,
-     UNARY_PLUS = 259,
-     tSUBTRACT = 260,
-     tADD = 261,
-     tXNOR = 262,
-     tXOR = 263,
-     tOR = 264,
-     tAND = 265,
-     MULTIPLICATION = 266,
-     tMOD = 267,
-     tDIVIDE = 268,
-     tMULTIPLY = 269,
-     tNOT = 270,
-     tROOT4 = 271,
-     tROOT3 = 272,
-     tROOT = 273,
-     tFUNCTION = 274,
-     tVARIABLE = 275,
-     tNSUPNUM = 276,
-     tSUPNUM = 277,
-     tSUBNUM = 278,
-     BOOLEAN_OPERATOR = 279,
-     PERCENTAGE = 280,
-     UNARY_MINUS = 281,
-     tIN = 282
+     tRCEILING = 259,
+     tLCEILING = 260,
+     tRFLOOR = 261,
+     tLFLOOR = 262,
+     UNARY_PLUS = 263,
+     tSUBTRACT = 264,
+     tADD = 265,
+     tXNOR = 266,
+     tXOR = 267,
+     tOR = 268,
+     tAND = 269,
+     MULTIPLICATION = 270,
+     tMULTIPLY = 271,
+     tMOD = 272,
+     tDIVIDE = 273,
+     tNOT = 274,
+     tROOT4 = 275,
+     tROOT3 = 276,
+     tROOT = 277,
+     tFUNCTION = 278,
+     tVARIABLE = 279,
+     tNSUPNUM = 280,
+     tSUPNUM = 281,
+     tSUBNUM = 282,
+     BOOLEAN_OPERATOR = 283,
+     PERCENTAGE = 284,
+     UNARY_MINUS = 285,
+     tIN = 286
    };
 #endif
 /* Tokens.  */
 #define tNUMBER 258
-#define UNARY_PLUS 259
-#define tSUBTRACT 260
-#define tADD 261
-#define tXNOR 262
-#define tXOR 263
-#define tOR 264
-#define tAND 265
-#define MULTIPLICATION 266
-#define tMOD 267
-#define tDIVIDE 268
-#define tMULTIPLY 269
-#define tNOT 270
-#define tROOT4 271
-#define tROOT3 272
-#define tROOT 273
-#define tFUNCTION 274
-#define tVARIABLE 275
-#define tNSUPNUM 276
-#define tSUPNUM 277
-#define tSUBNUM 278
-#define BOOLEAN_OPERATOR 279
-#define PERCENTAGE 280
-#define UNARY_MINUS 281
-#define tIN 282
+#define tRCEILING 259
+#define tLCEILING 260
+#define tRFLOOR 261
+#define tLFLOOR 262
+#define UNARY_PLUS 263
+#define tSUBTRACT 264
+#define tADD 265
+#define tXNOR 266
+#define tXOR 267
+#define tOR 268
+#define tAND 269
+#define MULTIPLICATION 270
+#define tMULTIPLY 271
+#define tMOD 272
+#define tDIVIDE 273
+#define tNOT 274
+#define tROOT4 275
+#define tROOT3 276
+#define tROOT 277
+#define tFUNCTION 278
+#define tVARIABLE 279
+#define tNSUPNUM 280
+#define tSUPNUM 281
+#define tSUBNUM 282
+#define BOOLEAN_OPERATOR 283
+#define PERCENTAGE 284
+#define UNARY_MINUS 285
+#define tIN 286
 
 
 
@@ -100,8 +106,8 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
-#line 160 "./mp-equation-parser.y"
+/* Line 2068 of yacc.c  */
+#line 166 "./mp-equation-parser.y"
 
   MPNumber int_t;
   int integer;
@@ -109,8 +115,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 1676 of yacc.c  */
-#line 114 "mp-equation-parser.h"
+/* Line 2068 of yacc.c  */
+#line 120 "mp-equation-parser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
